-file("/usr/local/lib/erlang/lib/parsetools-2.0.3/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(lfe_scan).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/lfe_scan.xrl", 98).
%% Copyright (c) 2008-2010 Robert Virding. All rights reserved.
%%
%% Redistribution and use in source and binary forms, with or without
%% modification, are permitted provided that the following conditions
%% are met:
%%
%% 1. Redistributions of source code must retain the above copyright
%%    notice, this list of conditions and the following disclaimer.
%% 2. Redistributions in binary form must reproduce the above copyright
%%    notice, this list of conditions and the following disclaimer in the
%%    documentation and/or other materials provided with the distribution.
%%
%% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
%% "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
%% LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
%% FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
%% COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
%% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
%% BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
%% LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
%% CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
%% LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
%% ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
%% POSSIBILITY OF SUCH DAMAGE.

%% File    : lfe_scan.erl
%% Author  : Robert Virding
%% Purpose : Token definitions for Lisp Flavoured Erlang.

-import(string, [substr/2,substr/3]).

%% base(Chars, Base, Line) -> Integer.
%% Convert a string of Base characters into a number. We know that
%% the strings only contain the correct character.

base(Cs, B, L) ->
    case base1(Cs, B, 0) of
	{N,[]} -> {token,{number,L,N}};
	{_,_} -> {error,"illegal based number"}
    end.

base1([C|Cs], Base, SoFar) when C >= $0, C =< $9, C < Base + $0 ->
    Next = SoFar * Base + (C - $0),
    base1(Cs, Base, Next);
base1([C|Cs], Base, SoFar) when C >= $a, C =< $f, C < Base + $a - 10 ->
    Next = SoFar * Base + (C - $a + 10),
    base1(Cs, Base, Next);
base1([C|Cs], Base, SoFar) when C >= $A, C =< $F, C < Base + $A - 10 ->
    Next = SoFar * Base + (C - $A + 10),
    base1(Cs, Base, Next);
base1([C|Cs], _Base, SoFar) -> {SoFar,[C|Cs]};
base1([], _Base, N) -> {N,[]}.

%% char(InputChars, Line) -> Char.
%% Convert an input string into the corresponding character. We know
%% that the input string is correct.

char([$x,C|Cs], L) ->
    case base1([C|Cs], 16, 0) of
	{N,[]} -> {token,{number,L,N}};
	_ -> {error,"illegal character"}
    end;
char([C], L) -> {token,{number,L,C}}.

%% chars(InputChars) -> Chars.
%% Convert an input string into the corresponding string
%% characters. We know that the input string is correct.

chars([$\\,$x,C|Cs0]) ->
    case hex_char(C) of
	true ->
	    case base1([C|Cs0], 16, 0) of
		{N,[$;|Cs1]} -> [N|chars(Cs1)];
		_Other -> [escape_char($x)|chars([C|Cs0])]
	    end;
	false -> [escape_char($x)|chars([C|Cs0])]
    end;
chars([$\\,C|Cs]) -> [escape_char(C)|chars(Cs)];
chars([C|Cs]) -> [C|chars(Cs)];
chars([]) -> [].

hex_char(C) when C >= $0, C =< $9 -> true;
hex_char(C) when C >= $a, C =< $f -> true;
hex_char(C) when C >= $A, C =< $F -> true;
hex_char(_) -> false.

escape_char($n) -> $\n;				%\n = LF
escape_char($r) -> $\r;				%\r = CR
escape_char($t) -> $\t;				%\t = TAB
escape_char($v) -> $\v;				%\v = VT
escape_char($b) -> $\b;				%\b = BS
escape_char($f) -> $\f;				%\f = FF
escape_char($e) -> $\e;				%\e = ESC
escape_char($s) -> $\s;				%\s = SPC
escape_char($d) -> $\d;				%\d = DEL
escape_char(C) -> C.

-file("/usr/local/lib/erlang/lib/parsetools-2.0.3/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,_Tlen,_Ics1,L1,_S1} ->
            string_cont(yysuf(Tcs, Alen), L1, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            token_cont(yysuf(Tcs, Alen1), L1, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            tokens_cont(yysuf(Tcs, Alen1), L1, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            skip_cont(yysuf(Tcs, Alen1), L1, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/lfe_scan.erl", 372).
yystate() -> 47.

yystate(50, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line};
yystate(49, [59|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(49, [10|Ics], Line, Tlen, _, _) ->
    yystate(49, Ics, Line+1, Tlen+1, 24, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(49, Ics, Line, Tlen+1, 24, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(49, Ics, Line, Tlen+1, 24, Tlen);
yystate(49, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,49};
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(48, Ics, Line, Tlen+1, 13, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(48, Ics, Line, Tlen+1, 13, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(48, Ics, Line, Tlen+1, 13, Tlen);
yystate(48, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,48};
yystate(47, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [33|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line+1, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 32 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 36, C =< 38 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(11, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,47};
yystate(46, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(46, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(46, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(46, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,46};
yystate(45, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(45, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,45};
yystate(44, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 119 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(44, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(44, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,44};
yystate(43, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line+1, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 91 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 123 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,43};
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(42, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(42, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(42, Ics, Line, Tlen+1, 19, Tlen);
yystate(42, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,42};
yystate(41, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line+1, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(39, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line};
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 55 ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(38, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,38};
yystate(37, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line};
yystate(36, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [111|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [100|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [98|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [96|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [88|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [68|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,36};
yystate(35, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(27, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line+1, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 91 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 119 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 121, C =< 123 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(35, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,35};
yystate(34, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 55 ->
    yystate(34, Ics, Line, Tlen+1, 17, Tlen);
yystate(34, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line,34};
yystate(33, [92|Ics], Line, Tlen, _, _) ->
    yystate(29, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, [34|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, [10|Ics], Line, Tlen, _, _) ->
    yystate(41, Ics, Line+1, Tlen+1, 14, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(41, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(41, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(41, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(41, Ics, Line, Tlen+1, 14, Tlen);
yystate(33, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line,33};
yystate(32, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line};
yystate(31, [124|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, [92|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, [10|Ics], Line, Tlen, _, _) ->
    yystate(43, Ics, Line+1, Tlen+1, 15, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(43, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 91 ->
    yystate(43, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 93, C =< 123 ->
    yystate(43, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, [C|Ics], Line, Tlen, _, _) when C >= 125 ->
    yystate(43, Ics, Line, Tlen+1, 15, Tlen);
yystate(31, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line,31};
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(30, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,30};
yystate(29, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line+1, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 119 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 121 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(29, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,29};
yystate(28, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line};
yystate(27, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line+1, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(27, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,27};
yystate(26, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(26, Ics, Line, Tlen+1, 18, Tlen);
yystate(26, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,26};
yystate(25, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line+1, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(11, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,24};
yystate(23, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line+1, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 47 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 60, C =< 64 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 103, C =< 123 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 125 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(23, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,23};
yystate(22, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(22, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,22};
yystate(21, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line+1, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 47 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 58, C =< 64 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 71, C =< 91 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 96 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 103 ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(21, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,21};
yystate(20, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(19, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(18, [48|Ics], Line, Tlen, _, _) ->
    yystate(18, Ics, Line, Tlen+1, 16, Tlen);
yystate(18, [49|Ics], Line, Tlen, _, _) ->
    yystate(18, Ics, Line, Tlen+1, 16, Tlen);
yystate(18, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line,18};
yystate(17, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(16, [64|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 9, Tlen);
yystate(16, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,16};
yystate(15, [59|Ics], Line, Tlen, _, _) ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [10|Ics], Line, Tlen, _, _) ->
    yystate(49, Ics, Line+1, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 32 ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 33, C =< 58 ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 60 ->
    yystate(15, Ics, Line, Tlen+1, 24, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line,15};
yystate(14, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(13, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(12, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 58 ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 11, Tlen);
yystate(12, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line,12};
yystate(11, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [47|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [46|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 45 ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(11, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 21, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line,11};
yystate(10, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(9, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line};
yystate(8, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,8};
yystate(7, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(3, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,7};
yystate(6, [114|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(6, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,6};
yystate(5, [64|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,5};
yystate(4, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(4, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line,4};
yystate(3, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [101|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [69|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 42, C =< 47 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(3, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 68 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 100 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 22, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line,3};
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(2, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,2};
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(1, Ics, Line, Tlen+1, 20, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(1, Ics, Line, Tlen+1, 20, Tlen);
yystate(1, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(1, Ics, Line, Tlen+1, 20, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line,1};
yystate(0, [124|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [92|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [58|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [46|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [47|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [45|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [44|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [43|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [42|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [33|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 39 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(4, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 60, C =< 90 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 94, C =< 122 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 126 ->
    yystate(45, Ics, Line, Tlen+1, 23, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, TokenLine) ->
    yyaction_0(TokenLine);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, _, _, TokenLine) ->
    yyaction_3(TokenLine);
yyaction(4, _, _, TokenLine) ->
    yyaction_4(TokenLine);
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, _, _, TokenLine) ->
    yyaction_10(TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_12(TokenChars, TokenLine);
yyaction(13, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_13(TokenChars, TokenLine);
yyaction(14, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_14(TokenChars, TokenLen, TokenLine);
yyaction(15, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_15(TokenChars, TokenLen, TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(22, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_22(TokenChars, TokenLine);
yyaction(23, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_23(TokenChars, TokenLine);
yyaction(24, _, _, _) ->
    yyaction_24();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("src/lfe_scan.xrl", 44).
yyaction_0(TokenLine) ->
     { token, { '#B(', TokenLine } } .

-compile({inline,yyaction_1/1}).
-file("src/lfe_scan.xrl", 45).
yyaction_1(TokenLine) ->
     { token, { '#(', TokenLine } } .

-compile({inline,yyaction_2/1}).
-file("src/lfe_scan.xrl", 46).
yyaction_2(TokenLine) ->
     { token, { '#\'', TokenLine } } .

-compile({inline,yyaction_3/1}).
-file("src/lfe_scan.xrl", 47).
yyaction_3(TokenLine) ->
     { token, { '#`', TokenLine } } .

-compile({inline,yyaction_4/1}).
-file("src/lfe_scan.xrl", 48).
yyaction_4(TokenLine) ->
     { token, { '#;', TokenLine } } .

-compile({inline,yyaction_5/1}).
-file("src/lfe_scan.xrl", 49).
yyaction_5(TokenLine) ->
     { token, { '#,', TokenLine } } .

-compile({inline,yyaction_6/1}).
-file("src/lfe_scan.xrl", 50).
yyaction_6(TokenLine) ->
     { token, { '#,@', TokenLine } } .

-compile({inline,yyaction_7/1}).
-file("src/lfe_scan.xrl", 51).
yyaction_7(TokenLine) ->
     { token, { '\'', TokenLine } } .

-compile({inline,yyaction_8/1}).
-file("src/lfe_scan.xrl", 52).
yyaction_8(TokenLine) ->
     { token, { '`', TokenLine } } .

-compile({inline,yyaction_9/1}).
-file("src/lfe_scan.xrl", 53).
yyaction_9(TokenLine) ->
     { token, { ',', TokenLine } } .

-compile({inline,yyaction_10/1}).
-file("src/lfe_scan.xrl", 54).
yyaction_10(TokenLine) ->
     { token, { ',@', TokenLine } } .

-compile({inline,yyaction_11/1}).
-file("src/lfe_scan.xrl", 55).
yyaction_11(TokenLine) ->
     { token, { '.', TokenLine } } .

-compile({inline,yyaction_12/2}).
-file("src/lfe_scan.xrl", 56).
yyaction_12(TokenChars, TokenLine) ->
     { token, { list_to_atom (TokenChars), TokenLine } } .

-compile({inline,yyaction_13/2}).
-file("src/lfe_scan.xrl", 58).
yyaction_13(TokenChars, TokenLine) ->
     char (string : substr (TokenChars, 3), TokenLine) .

-compile({inline,yyaction_14/3}).
-file("src/lfe_scan.xrl", 62).
yyaction_14(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     { token, { string, TokenLine, chars (S) } } .

-compile({inline,yyaction_15/3}).
-file("src/lfe_scan.xrl", 67).
yyaction_15(TokenChars, TokenLen, TokenLine) ->
     S = string : substr (TokenChars, 2, TokenLen - 2),
     { token, { symbol, TokenLine, list_to_atom (chars (S)) } } .

-compile({inline,yyaction_16/2}).
-file("src/lfe_scan.xrl", 70).
yyaction_16(TokenChars, TokenLine) ->
     base (string : substr (TokenChars, 3), 2, TokenLine) .

-compile({inline,yyaction_17/2}).
-file("src/lfe_scan.xrl", 71).
yyaction_17(TokenChars, TokenLine) ->
     base (string : substr (TokenChars, 3), 8, TokenLine) .

-compile({inline,yyaction_18/2}).
-file("src/lfe_scan.xrl", 72).
yyaction_18(TokenChars, TokenLine) ->
     base (string : substr (TokenChars, 3), 10, TokenLine) .

-compile({inline,yyaction_19/2}).
-file("src/lfe_scan.xrl", 73).
yyaction_19(TokenChars, TokenLine) ->
     base (string : substr (TokenChars, 3), 16, TokenLine) .

-compile({inline,yyaction_20/2}).
-file("src/lfe_scan.xrl", 76).
yyaction_20(TokenChars, TokenLine) ->
     { Base, [_ | Ds ] } = base1 (string : substr (TokenChars, 2), 10, 0),
     base (Ds, Base, TokenLine) .

-compile({inline,yyaction_21/2}).
-file("src/lfe_scan.xrl", 80).
yyaction_21(TokenChars, TokenLine) ->
     case catch { ok, list_to_integer (TokenChars) } of
     { ok, I } -> { token, { number, TokenLine, I } } ;
     _ -> { error, "illegal integer" }
     end .

-compile({inline,yyaction_22/2}).
-file("src/lfe_scan.xrl", 85).
yyaction_22(TokenChars, TokenLine) ->
     case catch { ok, list_to_float (TokenChars) } of
     { ok, F } -> { token, { number, TokenLine, F } } ;
     _ -> { error, "illegal float" }
     end .

-compile({inline,yyaction_23/2}).
-file("src/lfe_scan.xrl", 90).
yyaction_23(TokenChars, TokenLine) ->
     case catch { ok, list_to_atom (TokenChars) } of
     { ok, S } -> { token, { symbol, TokenLine, S } } ;
     _ -> { error, "illegal symbol" }
     end .

-compile({inline,yyaction_24/0}).
-file("src/lfe_scan.xrl", 94).
yyaction_24() ->
     skip_token .

-file("/usr/local/lib/erlang/lib/parsetools-2.0.3/include/leexinc.hrl", 282).
